@@ -4,9 +4,7 @@ from .column import Column
 class DoubleColumn(Column):
     
     def __init__(self, name, nullable, default=None, num_digits=None, num_decimal_digits=None):
-        super().__init__()
-        self.name = name
-        self.data_type = 'DOUBLE'
+        super().__init__(name, data_type='DOUBLE')
         self.num_digits = num_digits
         self.num_decimal_digits=num_decimal_digits
         self.nullable = nullable
