@@ -15,7 +15,11 @@ class Database():
         self.connection = connect(
             host=self.host,
             user=self.user,
-            password=self.password
+            password=self.password,
+            port='3306,'
+            auth_plugin='mysql_native_password',
+            use_pure=True,
+            ssl_disable=True
         )
         
         # check if database exists and create it if it doesn't exist
